@@ -1,6 +1,6 @@
 package WebService::Chroma;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use 5.006;
 use strict;
@@ -8,7 +8,19 @@ use warnings;
 
 use Moo;
 use WebService::Chroma::UA;
-use WebService::Chroma::Collection;
+use WebService::Chroma::Tenant;
+
+use MooX::ValidateSubs;
+use Types::Standard qw/Str ArrayRef HashRef/;
+
+validate_subs (
+	create_tenant => {
+		params => {
+			name => [Str]
+		}
+	}
+
+);
 
 has base_url => (
 	is => 'ro',
@@ -27,60 +39,51 @@ has ua => (
 
 sub version {
 	my ($self) = @_;
-	return $self->ua->get(url => '/api/v1/version');
+	return $self->ua->get(url => '/api/v2/version');
 }
 
-sub get_collections {
-	my ($self, $raw) = @_;
-	my $collections = $self->ua->get(url => '/api/v1/collections');
-	return $collections if $raw;
-	return [map {
-		WebService::Chroma::Collection->new(
-			ua => $self->ua,
-			%{$_}
-		);
-	} @{$collections}]
-
+sub reset {
+	my ($self) = @_;
+	return $self->ua->post(url => '/api/v2/reset');
 }
 
-sub get_collection {
-	my ($self, $name) = @_;
+sub heartbeat {
+	my ($self) = @_;
+	return $self->ua->get(url => '/api/v2/heartbeat');
+}
 
-	my $collection = $self->ua->get(url => '/api/v1/collections/' . $name);
+sub pre_flight_checks {
+	my ($self) = @_;
+	return $self->ua->get(url => '/api/v2/pre-flight-checks');
+}
+
+sub auth_identity {
+	my ($self) = @_;
+	return $self->ua->get(url => '/api/v2/auth/identity');
+}
+
+sub create_tenant {
+	my ($self, %data) = @_;
+
+	my $tenant = $self->ua->post(
+		url => '/api/v2/tenants',
+		data => \%data
+	);
+
+	return $self->get_tenant(%data);
+}
+
+sub get_tenant {
+	my ($self, %data) = @_;
+
+	my $tenant = $self->ua->get(url => '/api/v2/tenants/' . $data{name});
 	
-	return WebService::Chroma::Collection->new(
+	return WebService::Chroma::Tenant->new(
 		ua => $self->ua,
-		%{$collection}
+		%{$tenant}
 	);
 }
 
-sub create_collection {
-	my ($self, %options) = @_;
-
-	$options{configuration} = {};
-	$options{get_or_create} = \1;
-
-	my $collection = $self->ua->post(
-		url => '/api/v1/collections',
-		data => \%options
-	);
-
-	return WebService::Chroma::Collection->new(
-		ua => $self->ua,
-		%{$collection}
-	);
-}
-
-sub delete_collection {
-	my ($self, $name) = @_;
-
-	my $collection = $self->ua->delete(
-		url => '/api/v1/collections/' . $name
-	);
-
-	return $collection;
-}
-
 1;
 
 __END__
@@ -91,7 +94,7 @@ WebService::Chroma - chromadb client
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -103,7 +106,27 @@ Version 0.01
 
 	my $version = $chroma->version();
 
-	my $collection = $chroma->create_collection(
+	my $tenant = $chroma->create_tenant(
+		name => 'testing-tenant'
+	);
+
+	my $db = $tenant->create_database(
+		name => 'testing-db'
+	);
+
+	my $collection = $db->create_collection(
+		name => 'testing'
+	);
+
+	...
+
+	my $db = $chroma->get_tenant(
+		name => 'testing-tenant'
+	)->get_database(
+		name => 'testing-db'
+	);
+
+	my $collection = $db->get_collection(
 		name => 'testing'
 	);
 
@@ -148,13 +171,17 @@ L<http://localhost:8000/docs>
 
 =head2 version
 
-=head2 get_collections
+=head2 reset
 
-=head2 get_collection
+=head2 heartbeat
 
-=head2 create_collection
+=head2 pre_flight_checks
 
-=head2 delete_collection
+=head2 auth_identity
+
+=head2 create_tenant
+
+=head2 get_tenant
 
 =head1 AUTHOR
 
