@@ -7,6 +7,16 @@ has ua => (
 	required => 1,
 );
 
+has tenant => (
+	is => 'ro',
+	required => 1,
+);
+
+has db => (
+	is => 'ro',
+	required => 1,
+);
+
 has id => (
 	is => 'ro',
 	required => 1,
@@ -21,7 +31,7 @@ sub add {
 	my ($self, %data) = @_; 
 
 	return $self->ua->post(
-		url => sprintf("/api/v1/collections/%s/add", $self->id),
+		url => sprintf('/api/v2/tenants/%s/databases/%s/collections/%s/add', $self->tenant, $self->db, $self->id),
 		data => \%data
 	);
 }
@@ -30,7 +40,7 @@ sub upsert {
 	my ($self, %data) = @_; 
 	
 	return $self->ua->post(
-		url => sprintf("/api/v1/collections/%s/upsert", $self->id),
+		url => sprintf('/api/v2/tenants/%s/databases/%s/collections/%s/upsert', $self->tenant, $self->db, $self->id),
 		data => \%data
 	);
 }
@@ -39,7 +49,7 @@ sub update {
 	my ($self, %data) = @_; 
 	
 	return $self->ua->post(
-		url => sprintf("/api/v1/collections/%s/update", $self->id),
+		url => sprintf('/api/v2/tenants/%s/databases/%s/collections/%s/update', $self->tenant, $self->db, $self->id),
 		data => \%data
 	);
 }
@@ -48,7 +58,7 @@ sub get {
 	my ($self, %data) = @_;
 
 	return $self->ua->post(
-		url => sprintf("/api/v1/collections/%s/get", $self->id),
+		url => sprintf('/api/v2/tenants/%s/databases/%s/collections/%s/get', $self->tenant, $self->db, $self->id),
 		data => \%data
 	);
 }
@@ -57,7 +67,7 @@ sub query {
 	my ($self, %data) = @_;
 
 	return $self->ua->post(
-		url => sprintf("/api/v1/collections/%s/query", $self->id),
+		url => sprintf('/api/v2/tenants/%s/databases/%s/collections/%s/query', $self->tenant, $self->db, $self->id),
 		data => \%data
 	);
 }
@@ -66,7 +76,7 @@ sub delete {
 	my ($self, %data) = @_;
 	
 	return $self->ua->post(
-		url => sprintf("/api/v1/collections/%s/delete", $self->id),
+		url => sprintf('/api/v2/tenants/%s/databases/%s/collections/%s/delete', $self->tenant, $self->db, $self->id),
 		data => \%data
 	);
 }
@@ -81,7 +91,7 @@ WebService::Chroma::Collection - chromadb collection
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -91,6 +101,8 @@ Version 0.01
 
 	my $collection = WebService::Chroma::Collection->new(
 		ua => WebService::Chroma::UA->new(...),
+		tenant => '...',
+		db => '...',
 		id => '...',
 		name => '...',
 	);
