@@ -43,22 +43,26 @@ sub delete {
 	);
 }
 
-
 sub request {
 	my ($self, %params) = @_;
-
 	my $url = URI->new($self->base_url . $params{url});
-
 	my $res;
 	if ($params{type} eq 'GET') { 
+		$url->query_form($params{data});
 		$res = $self->ua->get($url);
 	} elsif ($params{type} eq 'DELETE') {
+		$url->query_form($params{data});
 		$res = $self->ua->delete($url);
 	} else {
-		$res = $self->ua->post($url, content => $self->json->encode($params{data}), 'Content-Type' => 'application/json' );
+		$res = $self->ua->post(
+			$url, 
+			content => $self->json->encode($params{data}), 
+			'Content-Type' => 'application/json'
+		);
 	}
 	return $self->response($res);
 }
+
 sub response {
 	my ($self, $res) = @_;
 
@@ -66,10 +70,8 @@ sub response {
 		my $content = $self->json->decode($res->decoded_content);
 		return $content;
 	}
-
-	use Data::Dumper;
-	warn Dumper $res;
-
+	
+	die $res->decoded_content;
 }
 
 1;
